==> laurelnetlib-0.0.10.tar.gz: laurelnetlib-0.0.10/sample/ClientSample.c <==
/*
    <ClientSample.c>>
ңУǺץ
     ꥨ ͥåȥңУǥ <ͥåȥط饤֥ꥵץ륽>
     Version 0.001, Dec 2002
     ------------------------------------------------------------
     Copyright (C) 2002ǯ naoki kuwamori<naoki@kuwamori.com>

     ܥץϥե꡼եȥǤʤϡFree Software Foundation
     ɽGNU ̸ͭѵΡ֥С󣲡װϤʹߤγƥС
     椫餤줫򤷡ΥС˽äܥץ
     ۤޤѹ뤳ȤǤޤ

    ʳΥ饤󥹤˾ξϡ᡼뤯.
    <naoki@kuwamori.com>


    Laurier Net work RPG server<game network library>
    Version 0.001, Dec 2002
    Copyright (C) 2002 Naoki Kuwamori <naoki@kuwamori.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or any
    later version.

    If you wish another license . 
    mail me <naoki@kuwamori.com> .

*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <stdlib.h>
#include <unistd.h>
#include <stdio.h>

#include "libnet.h"
/*ϤäȤ
#include "laurel/libnet.h"
*/
int dummyfunc(char *command , char * readbuf , int read_len , int resfd);
int helthcheck(char *command , char * readbuf , int read_len , int resfd);
int chdlevel(char *command , char * readbuf , int read_len , int resfd);
int endreq(char *command , char * readbuf , int read_len , int resfd);
int OnTimeup(char *command , char * readbuf , int read_len , int resfd);

#define DYMMYMES            "DYMMYMESGE"            /*ߡΥåݻ*/
#define HELTHCHK            "HELTHCHECK"            /*إ륹å*/
#define HELTHCHKOK          "HELTHCHKOK"            /*إ륹å*/
#define DBGLEVEL            "DEBUGLEVEL"            /*ǥХå٥륻å׵*/
#define ENDREQ              "ENDREQUEST"            /*λ׵*/
#define LAURELLOGSOCNAME    "/tmp/laurellog"
#define DEFAULTGAMENAME "laureltest"
#define CONFIGFILENAME "config_file.csv"
#define LAURELLOGFILENAME  "~/laurelserv.log"
#define LOGFUNCLEVEL        150

    int UNIXserverFD;
    int TCPserverFD;


/*TODO ץ
 * ʴǥեեƤ
 * ¤Τ*/
typedef struct{
	char hostname[1024];
	char portnom[1024];
	char UnixSocName[1024];
	char MMapFilePath[1024];
}config_file;

/*TODO ץ
 * եեΥƥץ졼Ȥ롣*/
static CCSVTemplate tmpl_templateConfig_file[] = { 
    CSVTRECORD( offsetof( config_file, hostname),CSV_string,1023), 
    CSVTRECORD( offsetof( config_file, portnom),CSV_string,1023), 
    CSVTRECORD( offsetof( config_file, UnixSocName),CSV_string,1023),
    CSVTRECORD( offsetof( config_file, MMapFilePath),CSV_string,1023),
    EndOfCSVTemplate
};


/*Хåؿ򥻥åȤ*/
/*Хåؿ򥻥åȤ빽¤Τ*/
typedef struct {
	    char event[11];             /* number of event */
		    int (*func)();  /* function address */
}EVTBL;
/*TODO ץ
 * ٥ȥޥåפ򤳤ˤ
 * ϥ٥ȤФ륳Хåؿ򤳤Ͽ롣*/
EVTBL eventkye[20] = {
         /* ٥             ؿ*/
        DYMMYMES,               dummyfunc,      /*ߡؿ*/
        HELTHCHK,               helthcheck,     /*إ륹å׵*/
        HELTHCHKOK,             helthcheck,     /*إ륹å*/
        DBGLEVEL,               chdlevel,       /*ǥХå٥ѹ׵*/
        ENDREQ,                 endreq,         /*λ׵*/
		POLLTIMEUP,				OnTimeup,
        "",                     NULL
};

char * gamename(char * lgamename){
    static char ggamename[MAXPATHLEN];
    static int flag=0;
    if (flag==0){
        bzero(ggamename,MAXPATHLEN);
        strncpy(ggamename,DEFAULTGAMENAME,MAXPATHLEN);
        flag=1;
    }
    if (lgamename!=NULL) strncpy(ggamename,lgamename,MAXPATHLEN);
    return ggamename;
}

char * logsockname(char * socname){
    static char gsockname[MAXPATHLEN];
    static int flag=0;
    if (flag==0){
        bzero(gsockname,MAXPATHLEN);
        strncpy(gsockname,LAURELLOGSOCNAME,MAXPATHLEN);
        flag=1;
    }
    if (socname!=NULL) strncpy(gsockname,socname,MAXPATHLEN);
    return gsockname;
}


/*ɤ߽ФƥåȤ*/
/*TODO ץ
 * ư˴ؤϤ
 * man getopt_long 򻲾Ȥ뤳*/
int set_opt(int argc, char *argv[]){
    int c;
    int digit_optind = 0;
    while (1)
    {
        int this_option_optind = optind ? optind : 1;
        int option_index = 0;
        static struct option long_options[] =
        {
           {"version", 0, 0, 'v'},
           {"help", 0, 0, 'h'},
           {"logfilename", 1, 0, 'f'},
           {"logsocname", 1, 0, 's'},
           {"debug", 1, 0, 'd'},
           {"gamename", 1, 0, 'g'},
           {0, 0, 0, 0}
        };
        c = getopt_long (argc, argv, "vhf:s:d:g:",
                    long_options, &option_index);
        if (c == -1) break;
        switch (c)
        {
           case 'v':
                printf ("LaurelRPG server\n");
                exit (1);
             break;
           case 'h':
                printf ("LaurelRPG server\n");
                exit (1);
             break;
           case 'f':
                rpg_setlogfile(optarg);
             break;
           case 's':
                logsockname(optarg);
             break;
           case 'd':
                rpg_dbglvl(atoi(optarg));
             break;
           case 'g':
                gamename(optarg);
             break;

           case '?':
             break;
           default:
             printf ("?? getopt returned character code 0%o ??\n", c);
        }
    }

    if (optind < argc)
    {
     printf ("nonoption ARGVelements: ");
     while (optind < argc)
     printf ("%s ", argv[optind++]);
     printf ("\n");
    }
}


int main (int argc, char *argv[])
{
    char readbuf[1025];
    char filepath[MAXPATHLEN];
    int read_len;
    char command[20];
    int resfd;
    int cnt;
    int ret;
    struct dirent *dieent;
	config_file testval;
	char *adder;
	FILE *fp;

    /*ǥեͤ򥻥åȤ*/
    rpg_dbglvl(101);
    rpg_setlogfile(LAURELLOGFILENAME);

    /*ᤷѿ˼Ǽ*/
    set_opt(argc,argv);

    /*ե졼եɤ߹*/

    /*եΥץ*/
    if (ret=  rpg_gamelog(RPGEMERGLEVEL ,"start loging" ) < 0){
        printf("logopnen error abort\n");
        exit (0);
    }

/*TODO ץ
 * CSVǤ줿ե졼եɤ߹߽*/
	fp = fopen (CONFIGFILENAME,"r");
	if (fp==NULL){
		printf("file open error\n");
		exit(0);
	}
	while ( fgets( readbuf, sizeof( readbuf ), fp ), !feof( fp ) ) {
		if (readbuf[0]=='#')continue; /*ȤλϹԤκǽʸˡ*/
		memset (&testval , 0 ,sizeof(config_file));
		if (FALSE==GetCSV( &testval, readbuf, tmpl_templateConfig_file )){
			printf("error of read cvs file\n");
		}   
		printf("print nom[%s] string[%s] Mmap\n", testval.portnom , testval.UnixSocName,testval.MMapFilePath);
		break;
	}


/*TODO ץ
 * ˥ååȡ̾դѥסˤΥ饤ȥץ*/
    /*ͥåȥΥץ(˥ååȤΥ饤ȥץ)*/
    UNIXserverFD = rpg_usoc_client_open(testval.UnixSocName );
    if (UNIXserverFD <= 0){
        rpglog("rpg_usoc_client_open error [%s] [%s] [%d]\n",testval.UnixSocName, strerror(errno) , ret);
        rpg_endproc(1);
    }
	
/*TODO ץ
 * ԣãХåȤΥ饤ȥץ*/
    TCPserverFD = rpg_tcp_client_open(testval.hostname,testval.portnom );
    if (TCPserverFD <= 0){
        rpglog("rpg_tcp_client_open error [%s] [%s] [%d]\n",testval.portnom, strerror(errno) , ret);
        rpg_endproc(1);
    }
    /*ͭγ*/
/*TODO ץ
 * ͣͣͭΥץ*/
    (char *)ret = rpg_mopen(testval.MMapFilePath);
    if ((char *)ret == NULL){
        rpg_gamelog (RPGEMERGLEVEL,"cant open mmmap\n");
        rpg_endproc(RPG_NG);
    }
    adder = (char *)ret;

/*TODO ץ*/
    /*λΤǥǡˤʤ*/
    ret = fork();
    if (ret > 0){
        if (ret==1){
            rpg_gamelog (RPGEMERGLEVEL,"cant fork child prosses\n");
        }
        exit (1);
    }

    /*ᥤ롼*/
    while (1){
        char errbuf[2024];
        memset (readbuf , 0 , 1024);
        ret = RPG_Poll (command ,  readbuf , 1024, &read_len , 10000 , &resfd );
        readbuf[1023]=0;
        printf ( "ret %d [%s] \n" , ret , command );
        for (cnt=0;cnt<20;cnt++){
            if (eventkye[cnt].func==NULL)break;
                /*ޥʸӤפ*/
            if (strncmp(command ,eventkye[cnt].event,COMMANDLEN)==0){
                /*ХåؿƤӽФ*/
                ret = eventkye[cnt].func(command ,readbuf,read_len , resfd);
            }
        }
    }
    return RPG_OK;
}

/*ߡؿ*/
int dummyfunc(char *command , char * readbuf , int read_len , int resfd){
    rpg_gamelog(LOGFUNCLEVEL , "dummyfunc");

    return RPG_OK;
}
/*إ륹åؿ׵ξ*/
int helthcheck(char *command , char * readbuf , int read_len , int resfd){
    rpg_gamelog(LOGFUNCLEVEL , "helthcheck");

    /*ֿ*/
    if (memcmp(HELTHCHK,command,COMMANDLEN)==0){
        rpg_send(resfd,HELTHCHKOK,"",0);
    }else{
		rpg_send(UNIXserverFD,DYMMYMES , "",0);
	}
    return RPG_OK;
}
/*ǥХå٥ѹ׵*/
int chdlevel(char *command , char * readbuf , int read_len , int resfd){
    int rev;
    rpg_gamelog(LOGFUNCLEVEL , "chdlevel");
    /*ӥåǥб*/
    rev = ntohl (*((int *)readbuf));
    rpg_dbglvl(rev);
    return RPG_OK;
}
/*λ׵*/
int endreq(char *command , char * readbuf , int read_len , int resfd){
    rpg_gamelog(LOGFUNCLEVEL , "endreq");
    rpg_fd_allclose();
    rpg_gamelog(-1,"end log file");
	exit(0);
}

int OnTimeup(char *command , char * readbuf , int read_len , int resfd){
    rpg_gamelog(LOGFUNCLEVEL , "OnTimeup");
	rpg_send( TCPserverFD, HELTHCHK , "",0);

}

==> laurelnetlib-0.0.11.tar.gz: laurelnetlib-0.0.11/sample/ClientSample.c <==
/*
    <ClientSample.c>>
ңУǺץ
     ꥨ ͥåȥңУǥ <ͥåȥط饤֥ꥵץ륽>
     Version 0.001, Dec 2002
     ------------------------------------------------------------
     Copyright (C) 2002ǯ naoki kuwamori<naoki@kuwamori.com>

     ܥץϥե꡼եȥǤʤϡFree Software Foundation
     ɽGNU ̸ͭѵΡ֥С󣲡װϤʹߤγƥС
     椫餤줫򤷡ΥС˽äܥץ
     ۤޤѹ뤳ȤǤޤ

    ʳΥ饤󥹤˾ξϡ᡼뤯.
    <naoki@kuwamori.com>


    Laurier Net work RPG server<game network library>
    Version 0.001, Dec 2002
    Copyright (C) 2002 Naoki Kuwamori <naoki@kuwamori.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or any
    later version.

    If you wish another license . 
    mail me <naoki@kuwamori.com> .

*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <stdlib.h>
#include <unistd.h>
#include <stdio.h>

#include "libnet.h"
/*ϤäȤ
#include "laurel/libnet.h"
*/
int dummyfunc(char *command , char * readbuf , int read_len , int resfd);
int helthcheck(char *command , char * readbuf , int read_len , int resfd);
int chdlevel(char *command , char * readbuf , int read_len , int resfd);
int endreq(char *command , char * readbuf , int read_len , int resfd);
int OnTimeup(char *command , char * readbuf , int read_len , int resfd);

#define DYMMYMES            "DYMMYMESGE"            /*ߡΥåݻ*/
#define HELTHCHK            "HELTHCHECK"            /*إ륹å*/
#define HELTHCHKOK          "HELTHCHKOK"            /*إ륹å*/
#define DBGLEVEL            "DEBUGLEVEL"            /*ǥХå٥륻å׵*/
#define ENDREQ              "ENDREQUEST"            /*λ׵*/
#define LAURELLOGSOCNAME    "/tmp/laurellog"
#define DEFAULTGAMENAME "laureltest"
#define CONFIGFILENAME "config_file.csv"
#define LAURELLOGFILENAME  "laurelsampcli.log"
#define LOGFUNCLEVEL        150

    int UNIXserverFD;
    int TCPserverFD;


/*TODO ץ
 * ʴǥեեƤ
 * ¤Τ*/
typedef struct{
	char hostname[1024];
	char portnom[1024];
	char UnixSocName[1024];
	char MMapFilePath[1024];
}config_file;

/*TODO ץ
 * եեΥƥץ졼Ȥ롣*/
static CCSVTemplate tmpl_templateConfig_file[] = { 
    CSVTRECORD( offsetof( config_file, hostname),CSV_string,1023), 
    CSVTRECORD( offsetof( config_file, portnom),CSV_string,1023), 
    CSVTRECORD( offsetof( config_file, UnixSocName),CSV_string,1023),
    CSVTRECORD( offsetof( config_file, MMapFilePath),CSV_string,1023),
    EndOfCSVTemplate
};


/*Хåؿ򥻥åȤ*/
/*Хåؿ򥻥åȤ빽¤Τ*/
typedef struct {
	    char event[11];             /* number of event */
		    int (*func)();  /* function address */
}EVTBL;
/*TODO ץ
 * ٥ȥޥåפ򤳤ˤ
 * ϥ٥ȤФ륳Хåؿ򤳤Ͽ롣*/
EVTBL eventkye[20] = {
         /* ٥             ؿ*/
        DYMMYMES,               dummyfunc,      /*ߡؿ*/
        HELTHCHK,               helthcheck,     /*إ륹å׵*/
        HELTHCHKOK,             helthcheck,     /*إ륹å*/
        DBGLEVEL,               chdlevel,       /*ǥХå٥ѹ׵*/
        ENDREQ,                 endreq,         /*λ׵*/
		POLLTIMEUP,				OnTimeup,
        "",                     NULL
};

char * gamename(char * lgamename){
    static char ggamename[MAXPATHLEN];
    static int flag=0;
    if (flag==0){
        bzero(ggamename,MAXPATHLEN);
        strncpy(ggamename,DEFAULTGAMENAME,MAXPATHLEN);
        flag=1;
    }
    if (lgamename!=NULL) strncpy(ggamename,lgamename,MAXPATHLEN);
    return ggamename;
}

char * logsockname(char * socname){
    static char gsockname[MAXPATHLEN];
    static int flag=0;
    if (flag==0){
        bzero(gsockname,MAXPATHLEN);
        strncpy(gsockname,LAURELLOGSOCNAME,MAXPATHLEN);
        flag=1;
    }
    if (socname!=NULL) strncpy(gsockname,socname,MAXPATHLEN);
    return gsockname;
}


/*ɤ߽ФƥåȤ*/
/*TODO ץ
 * ư˴ؤϤ
 * man getopt_long 򻲾Ȥ뤳*/
int set_opt(int argc, char *argv[]){
    int c;
    int digit_optind = 0;
    while (1)
    {
        int this_option_optind = optind ? optind : 1;
        int option_index = 0;
        static struct option long_options[] =
        {
           {"version", 0, 0, 'v'},
           {"help", 0, 0, 'h'},
           {"logfilename", 1, 0, 'f'},
           {"logsocname", 1, 0, 's'},
           {"debug", 1, 0, 'd'},
           {"gamename", 1, 0, 'g'},
           {0, 0, 0, 0}
        };
        c = getopt_long (argc, argv, "vhf:s:d:g:",
                    long_options, &option_index);
        if (c == -1) break;
        switch (c)
        {
           case 'v':
                printf ("LaurelRPG server\n");
                exit (1);
             break;
           case 'h':
                printf ("LaurelRPG server\n");
                exit (1);
             break;
           case 'f':
                rpg_setlogfile(optarg);
             break;
           case 's':
                logsockname(optarg);
             break;
           case 'd':
                rpg_dbglvl(atoi(optarg));
             break;
           case 'g':
                gamename(optarg);
             break;

           case '?':
             break;
           default:
             printf ("?? getopt returned character code 0%o ??\n", c);
        }
    }

    if (optind < argc)
    {
     printf ("nonoption ARGVelements: ");
     while (optind < argc)
     printf ("%s ", argv[optind++]);
     printf ("\n");
    }
}


int main (int argc, char *argv[])
{
    char readbuf[1025];
    char filepath[MAXPATHLEN];
    int read_len;
    char command[20];
    int resfd;
    int cnt;
    int ret;
    struct dirent *dieent;
	config_file testval;
	char *adder;
	FILE *fp;

    /*ǥեͤ򥻥åȤ*/
    rpg_dbglvl(101);
    rpg_setlogfile(LAURELLOGFILENAME);

    /*ᤷѿ˼Ǽ*/
    set_opt(argc,argv);

    /*ե졼եɤ߹*/

    /*եΥץ*/
    if (ret=  rpglog(RPGEMERGLEVEL ,"start loging\n" ) < 0){
        printf("logopnen error abort\n");
        exit (0);
    }

/*TODO ץ
 * CSVǤ줿ե졼եɤ߹߽*/
	fp = fopen (CONFIGFILENAME,"r");
	if (fp==NULL){
		printf("file open error\n");
		exit(0);
	}
	while ( fgets( readbuf, sizeof( readbuf ), fp ), !feof( fp ) ) {
		if (readbuf[0]=='#')continue; /*ȤλϹԤκǽʸˡ*/
		memset (&testval , 0 ,sizeof(config_file));
		if (FALSE==GetCSV( &testval, readbuf, tmpl_templateConfig_file )){
			printf("error of read cvs file\n");
		}   
		printf("print nom[%s] string[%s] Mmap\n", testval.portnom , testval.UnixSocName,testval.MMapFilePath);
		break;
	}


/*TODO ץ
 * ˥ååȡ̾դѥסˤΥ饤ȥץ*/
    /*ͥåȥΥץ(˥ååȤΥ饤ȥץ)*/
    UNIXserverFD = rpg_usoc_client_open(testval.UnixSocName );
    if (UNIXserverFD <= 0){
        rpglog(RPGEMERGLEVEL,"rpg_usoc_client_open error [%s] [%s] [%d]\n",testval.UnixSocName, strerror(errno) , ret);
        rpg_endproc(1);
    }
	
/*TODO ץ
 * ԣãХåȤΥ饤ȥץ*/
    TCPserverFD = rpg_tcp_client_open(testval.hostname,testval.portnom );
    if (TCPserverFD <= 0){
        rpglog(RPGEMERGLEVEL,"rpg_tcp_client_open error [%s] [%s] [%d]\n",testval.portnom, strerror(errno) , ret);
        rpg_endproc(1);
    }
    /*ͭγ*/
/*TODO ץ
 * ͣͣͭΥץ*/
    (char *)ret = rpg_mopen(testval.MMapFilePath);
    if ((char *)ret == NULL){
        rpglog (RPGEMERGLEVEL,"cant open mmmap\n");
        rpg_endproc(RPG_NG);
    }
    adder = (char *)ret;

/*TODO ץ*/
    /*ФȤΥå³*/
    ret = rpg_loginit( argv[0] , LAURELLOGSOCNAME);
    if (ret < 0){
        rpglog (RPGEMERGLEVEL,"cant connect log server\n");
    }


/*TODO ץ*/
    /*λΤǥǡˤʤ*/
    ret = fork();
    if (ret > 0){
        if (ret==1){
            rpglog (RPGEMERGLEVEL,"cant fork child prosses\n");
        }
        exit (1);
    }

    /*ᥤ롼*/
    while (1){
        char errbuf[2024];
        memset (readbuf , 0 , 1024);
        ret = RPG_Poll (command ,  readbuf , 1024, &read_len , 10000 , &resfd );
        readbuf[1023]=0;
        printf ( "ret %d [%s] \n" , ret , command );
        for (cnt=0;cnt<20;cnt++){
            if (eventkye[cnt].func==NULL)break;
                /*ޥʸӤפ*/
            if (strncmp(command ,eventkye[cnt].event,COMMANDLEN)==0){
                /*ХåؿƤӽФ*/
                ret = eventkye[cnt].func(command ,readbuf,read_len , resfd);
            }
        }
    }
    return RPG_OK;
}

/*ߡؿ*/
int dummyfunc(char *command , char * readbuf , int read_len , int resfd){
    rpglog(LOGFUNCLEVEL , "dummyfunc\n");

    return RPG_OK;
}
/*إ륹åؿ׵ξ*/
int helthcheck(char *command , char * readbuf , int read_len , int resfd){
    rpglog(LOGFUNCLEVEL , "helthcheck\n");

    /*ֿ*/
    if (memcmp(HELTHCHK,command,COMMANDLEN)==0){
        rpg_send(resfd,HELTHCHKOK,"",0);
    }else{
		rpg_send(UNIXserverFD,DYMMYMES , "",0);
	}
    return RPG_OK;
}
/*ǥХå٥ѹ׵*/
int chdlevel(char *command , char * readbuf , int read_len , int resfd){
    int rev;
    rpglog(LOGFUNCLEVEL , "chdlevel\n");
    /*ӥåǥб*/
    rev = ntohl (*((int *)readbuf));
    rpg_dbglvl(rev);
    return RPG_OK;
}
/*λ׵*/
int endreq(char *command , char * readbuf , int read_len , int resfd){
    rpglog(LOGFUNCLEVEL , "endreq\n");
    rpg_fd_allclose();
    rpglog(-1,"end log file\n");
	exit(0);
}

int OnTimeup(char *command , char * readbuf , int read_len , int resfd){
    rpglog(LOGFUNCLEVEL , "OnTimeup\n");
    rpglog(LOGFUNCLEVEL , "OnTimeup\n");
	rpg_send( TCPserverFD, HELTHCHK , "",0);

}
